.. _installation:

================
Installation
================

EEGDash is written in Python 3, specifically for version 3.8 or above.

The package is distributed via Python package index (`PyPI <eegdash-pypi_>`_), and you can access the
source code via `Github <eegdash-github_>`_ repository.

There are different ways to install EEGDash, depending on your needs and:


.. grid:: 2

    .. grid-item-card::
        :text-align: center

        .. rst-class:: font-weight-bold mb-0

            Install via ``pip``

        .. rst-class:: card-subtitle text-muted mt-0

            For Beginners

        ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
        .. image:: /_static/eegdash_install.gif
           :alt: EEGDash Installer with pip

        +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++


        .. button-ref:: install_pip
            :ref-type: ref
            :color: primary
            :shadow:
            :class: font-weight-bold

            Installing from PyPI


    .. grid-item-card::
        :text-align: center

        .. rst-class:: font-weight-bold mb-0

           Building from source code

        .. rst-class:: card-subtitle text-muted mt-0

            For Advanced Users

        ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
        .. image:: https://mne.tools/stable/_images/mne_installer_console.png
           :alt: Terminal Window

        **Already familiar with Python?**
        Follow our setup instructions for building from Github and start to contribute!
        +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

        .. button-ref:: install_source
            :ref-type: ref
            :color: primary
            :shadow:
            :class: font-weight-bold

            From Source Code

.. toctree::
    :hidden:

    install_pip
    install_source

.. include:: /links.inc
